# Generated by Django 3.1 on 2020-10-08 11:19

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='MetaTag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.CharField(max_length=50, unique=True)),
                ('title', models.CharField(max_length=50)),
                ('desc', models.CharField(max_length=100)),
                ('keywords', models.CharField(max_length=100)),
                ('author', models.CharField(max_length=50)),
                ('index', models.BooleanField(default=True)),
                ('follow', models.BooleanField(default=True)),
            ],
        ),
    ]



from django.db import models

class MetaTag(models.Model):
    slug = models.CharField(max_length=50, unique=True)
    title = models.CharField(max_length=50)
    desc = models.CharField(max_length=100)
    keywords = models.CharField(max_length=100)
    author = models.CharField(max_length=50)
    index = models.BooleanField(default=True)
    follow = models.BooleanField(default=True)

    def __str__(self):
        return self.slug


from django import template
from django.utils.safestring import mark_safe
from metatags.models import MetaTag
from django.db.models import F, Value, CharField



register = template.Library()


@register.simple_tag
def metatags(site_slug):
    try:
        meta = MetaTag.objects.annotate(site_slug_field=Value(site_slug, output_field=CharField())).filter(site_slug_field__contains=F('slug'))[0]
        metaData = f'''
        
    <meta name="description" content="{meta.desc}">
    <meta name="keywords" content="{meta.keywords}">
    <meta name="author" content="{meta.author}">
    <meta name="title" content="{meta.title}">       
        '''
        if meta.index:
            metaData += ''' 
    <meta name="googlebot" content="index" />
    <meta name="robots" content="index" />
            '''
        else:
            metaData += ''' 
    <meta name="googlebot" content="noindex" />
    <meta name="robots" content="noindex" />
            '''

        if meta.follow:
            metaData += ''' 
    <meta name="googlebot" content="follow" />
    <meta name="robots" content="follow" />
            '''
        else:
            metaData += ''' 
    <meta name="googlebot" content="nofollow" />
    <meta name="robots" content="nofollow" />
            '''


        return mark_safe(metaData)
    except:
        return mark_safe('')